@@ -86,7 +86,7 @@ def discover_files (start_dir, suffix):
     
 
 def execute_command (command_and_arguments, outfile_name, env=None, cwd=None,
-                     error_file_name=None):
+                     error_file_name=None, shell=False):
     if error_file_name is None:
         error_file_name = outfile_name + ".err"
     
@@ -97,7 +97,7 @@ def execute_command (command_and_arguments, outfile_name, env=None, cwd=None,
                                        stderr=error_file,
                                        env=env,
                                        cwd=cwd,
-                                       shell=False)
+                                       shell=shell)
             return process.wait()
     
 def assert_can_execute (command_and_arguments, prerequisite, caller):
@@ -162,3 +162,19 @@ class GlobExpression (object):
         if self.pattern.match(path):
             return True
         return False
+
+def mkdir (directory):
+    """
+    Tries to create the directory denoted by the given name. If it exists and is a directory, nothing will be created
+    and no error is raised. If it exists as a file a PythonbuilderException is raised. Otherwise the directory incl.
+    all parents is created.
+
+
+    """
+
+    if os.path.exists(directory):
+        if os.path.isfile(directory):
+            raise PythonbuilderException("Unable to created directory '%s': A file with that name already exists",
+                directory)
+        return
+    os.makedirs(directory)
